@@ -7,7 +7,7 @@ pathtoname() {
 MOUNT_OPTIONS="ro,flush"
 
 rmdir /media/* &> /dev/null || true
-for DEVNAME in $(udisks --enumerate-device-files|grep -e sd[a-z][0-9]); do
+for DEVNAME in $(udisks --enumerate-device-files|grep -e sd[a-z]); do
 	udisks --mount-options $MOUNT_OPTIONS --mount $DEVNAME
 done
 
