@@ -1785,7 +1785,7 @@ int plane_setup(window_data_t *window, int i, texture_data_t *texture, texture_d
     }
 
     /* ...get plane identifier */
-    CHK_ERR(plane_id = display->plane_id[i], -(errno = ENODEV));
+    CHK_ERR(plane_id = display->plane_id[i + output->id * 5], -(errno = ENODEV));
 
     t1 = __get_time_usec();
 
